==> puppetlabs-dsc-0.8.1.tar.gz: puppetlabs-dsc-0.8.1/spec/unit/puppet/type/dsc_xexchantimalwarescanning_spec.rb <==
#!/usr/bin/env ruby
require 'spec_helper'

describe Puppet::Type.type(:dsc_xexchantimalwarescanning) do

  let :dsc_xexchantimalwarescanning do
    Puppet::Type.type(:dsc_xexchantimalwarescanning).new(
      :name     => 'foo',
      :dsc_enabled => true,
    )
  end

  it "should stringify normally" do
    expect(dsc_xexchantimalwarescanning.to_s).to eq("Dsc_xexchantimalwarescanning[foo]")
  end

  it 'should require that dsc_enabled is specified' do
    #dsc_xexchantimalwarescanning[:dsc_enabled]
    expect { Puppet::Type.type(:dsc_xexchantimalwarescanning).new(
      :name     => 'foo',
      :dsc_credential => 'foo',
      :dsc_allowservicerestart => true,
    )}.to raise_error(Puppet::Error, /dsc_enabled is a required attribute/)
  end

  it 'should not accept array for dsc_enabled' do
    expect{dsc_xexchantimalwarescanning[:dsc_enabled] = ["foo", "bar", "spec"]}.to raise_error(Puppet::ResourceError)
  end

  it 'should accept boolean for dsc_enabled' do
    dsc_xexchantimalwarescanning[:dsc_enabled] = true
    expect(dsc_xexchantimalwarescanning[:dsc_enabled]).to eq(true)
  end

  it "should accept boolean-like value 'true' and munge this value to boolean for dsc_enabled" do
    dsc_xexchantimalwarescanning[:dsc_enabled] = 'true'
    expect(dsc_xexchantimalwarescanning[:dsc_enabled]).to eq(true)
  end

  it "should accept boolean-like value 'false' and munge this value to boolean for dsc_enabled" do
    dsc_xexchantimalwarescanning[:dsc_enabled] = 'false'
    expect(dsc_xexchantimalwarescanning[:dsc_enabled]).to eq(false)
  end

  it "should accept boolean-like value 'True' and munge this value to boolean for dsc_enabled" do
    dsc_xexchantimalwarescanning[:dsc_enabled] = 'True'
    expect(dsc_xexchantimalwarescanning[:dsc_enabled]).to eq(true)
  end

  it "should accept boolean-like value 'False' and munge this value to boolean for dsc_enabled" do
    dsc_xexchantimalwarescanning[:dsc_enabled] = 'False'
    expect(dsc_xexchantimalwarescanning[:dsc_enabled]).to eq(false)
  end

  it "should accept boolean-like value :true and munge this value to boolean for dsc_enabled" do
    dsc_xexchantimalwarescanning[:dsc_enabled] = :true
    expect(dsc_xexchantimalwarescanning[:dsc_enabled]).to eq(true)
  end

  it "should accept boolean-like value :false and munge this value to boolean for dsc_enabled" do
    dsc_xexchantimalwarescanning[:dsc_enabled] = :false
    expect(dsc_xexchantimalwarescanning[:dsc_enabled]).to eq(false)
  end

  it 'should not accept int for dsc_enabled' do
    expect{dsc_xexchantimalwarescanning[:dsc_enabled] = -16}.to raise_error(Puppet::ResourceError)
  end

  it 'should not accept uint for dsc_enabled' do
    expect{dsc_xexchantimalwarescanning[:dsc_enabled] = 16}.to raise_error(Puppet::ResourceError)
  end

  it 'should not accept array for dsc_credential' do
    expect{dsc_xexchantimalwarescanning[:dsc_credential] = ["foo", "bar", "spec"]}.to raise_error(Puppet::ResourceError)
  end

  it 'should not accept boolean for dsc_credential' do
    expect{dsc_xexchantimalwarescanning[:dsc_credential] = true}.to raise_error(Puppet::ResourceError)
  end

  it 'should not accept int for dsc_credential' do
    expect{dsc_xexchantimalwarescanning[:dsc_credential] = -16}.to raise_error(Puppet::ResourceError)
  end

  it 'should not accept uint for dsc_credential' do
    expect{dsc_xexchantimalwarescanning[:dsc_credential] = 16}.to raise_error(Puppet::ResourceError)
  end

  it 'should not accept array for dsc_allowservicerestart' do
    expect{dsc_xexchantimalwarescanning[:dsc_allowservicerestart] = ["foo", "bar", "spec"]}.to raise_error(Puppet::ResourceError)
  end

  it 'should accept boolean for dsc_allowservicerestart' do
    dsc_xexchantimalwarescanning[:dsc_allowservicerestart] = true
    expect(dsc_xexchantimalwarescanning[:dsc_allowservicerestart]).to eq(true)
  end

  it "should accept boolean-like value 'true' and munge this value to boolean for dsc_allowservicerestart" do
    dsc_xexchantimalwarescanning[:dsc_allowservicerestart] = 'true'
    expect(dsc_xexchantimalwarescanning[:dsc_allowservicerestart]).to eq(true)
  end

  it "should accept boolean-like value 'false' and munge this value to boolean for dsc_allowservicerestart" do
    dsc_xexchantimalwarescanning[:dsc_allowservicerestart] = 'false'
    expect(dsc_xexchantimalwarescanning[:dsc_allowservicerestart]).to eq(false)
  end

  it "should accept boolean-like value 'True' and munge this value to boolean for dsc_allowservicerestart" do
    dsc_xexchantimalwarescanning[:dsc_allowservicerestart] = 'True'
    expect(dsc_xexchantimalwarescanning[:dsc_allowservicerestart]).to eq(true)
  end

  it "should accept boolean-like value 'False' and munge this value to boolean for dsc_allowservicerestart" do
    dsc_xexchantimalwarescanning[:dsc_allowservicerestart] = 'False'
    expect(dsc_xexchantimalwarescanning[:dsc_allowservicerestart]).to eq(false)
  end

  it "should accept boolean-like value :true and munge this value to boolean for dsc_allowservicerestart" do
    dsc_xexchantimalwarescanning[:dsc_allowservicerestart] = :true
    expect(dsc_xexchantimalwarescanning[:dsc_allowservicerestart]).to eq(true)
  end

  it "should accept boolean-like value :false and munge this value to boolean for dsc_allowservicerestart" do
    dsc_xexchantimalwarescanning[:dsc_allowservicerestart] = :false
    expect(dsc_xexchantimalwarescanning[:dsc_allowservicerestart]).to eq(false)
  end

  it 'should not accept int for dsc_allowservicerestart' do
    expect{dsc_xexchantimalwarescanning[:dsc_allowservicerestart] = -16}.to raise_error(Puppet::ResourceError)
  end

  it 'should not accept uint for dsc_allowservicerestart' do
    expect{dsc_xexchantimalwarescanning[:dsc_allowservicerestart] = 16}.to raise_error(Puppet::ResourceError)
  end

  # Configuration PROVIDER TESTS

  describe "powershell provider tests" do

    it "should successfully instanciate the provider" do
      described_class.provider(:powershell).new(dsc_xexchantimalwarescanning)
    end

    before(:each) do
      @provider = described_class.provider(:powershell).new(dsc_xexchantimalwarescanning)
    end

    describe "when dscmeta_import_resource is true (default) and dscmeta_module_name existing/is defined " do

      it "should compute powershell dsc test script with Invoke-DscResource" do
        expect(@provider.ps_script_content('test')).to match(/Invoke-DscResource/)
      end

      it "should compute powershell dsc test script with method Test" do
        expect(@provider.ps_script_content('test')).to match(/Method\s+=\s*'test'/)
      end

      it "should compute powershell dsc set script with Invoke-DscResource" do
        expect(@provider.ps_script_content('set')).to match(/Invoke-DscResource/)
      end

      it "should compute powershell dsc test script with method Set" do
        expect(@provider.ps_script_content('set')).to match(/Method\s+=\s*'set'/)
      end

    end

  end
end

==> puppetlabs-dsc-1.0.0.tar.gz: puppetlabs-dsc-1.0.0/spec/unit/puppet/type/dsc_xexchantimalwarescanning_spec.rb <==
#!/usr/bin/env ruby
require 'spec_helper'

describe Puppet::Type.type(:dsc_xexchantimalwarescanning) do

  let :dsc_xexchantimalwarescanning do
    Puppet::Type.type(:dsc_xexchantimalwarescanning).new(
      :name     => 'foo',
      :dsc_enabled => true,
    )
  end

  it "should stringify normally" do
    expect(dsc_xexchantimalwarescanning.to_s).to eq("Dsc_xexchantimalwarescanning[foo]")
  end

  it 'should require that dsc_enabled is specified' do
    #dsc_xexchantimalwarescanning[:dsc_enabled]
    expect { Puppet::Type.type(:dsc_xexchantimalwarescanning).new(
      :name     => 'foo',
      :dsc_credential => {"user"=>"user", "password"=>"password"},
      :dsc_allowservicerestart => true,
    )}.to raise_error(Puppet::Error, /dsc_enabled is a required attribute/)
  end

  it 'should not accept array for dsc_enabled' do
    expect{dsc_xexchantimalwarescanning[:dsc_enabled] = ["foo", "bar", "spec"]}.to raise_error(Puppet::ResourceError)
  end

  it 'should accept boolean for dsc_enabled' do
    dsc_xexchantimalwarescanning[:dsc_enabled] = true
    expect(dsc_xexchantimalwarescanning[:dsc_enabled]).to eq(true)
  end

  it "should accept boolean-like value 'true' and munge this value to boolean for dsc_enabled" do
    dsc_xexchantimalwarescanning[:dsc_enabled] = 'true'
    expect(dsc_xexchantimalwarescanning[:dsc_enabled]).to eq(true)
  end

  it "should accept boolean-like value 'false' and munge this value to boolean for dsc_enabled" do
    dsc_xexchantimalwarescanning[:dsc_enabled] = 'false'
    expect(dsc_xexchantimalwarescanning[:dsc_enabled]).to eq(false)
  end

  it "should accept boolean-like value 'True' and munge this value to boolean for dsc_enabled" do
    dsc_xexchantimalwarescanning[:dsc_enabled] = 'True'
    expect(dsc_xexchantimalwarescanning[:dsc_enabled]).to eq(true)
  end

  it "should accept boolean-like value 'False' and munge this value to boolean for dsc_enabled" do
    dsc_xexchantimalwarescanning[:dsc_enabled] = 'False'
    expect(dsc_xexchantimalwarescanning[:dsc_enabled]).to eq(false)
  end

  it "should accept boolean-like value :true and munge this value to boolean for dsc_enabled" do
    dsc_xexchantimalwarescanning[:dsc_enabled] = :true
    expect(dsc_xexchantimalwarescanning[:dsc_enabled]).to eq(true)
  end

  it "should accept boolean-like value :false and munge this value to boolean for dsc_enabled" do
    dsc_xexchantimalwarescanning[:dsc_enabled] = :false
    expect(dsc_xexchantimalwarescanning[:dsc_enabled]).to eq(false)
  end

  it 'should not accept int for dsc_enabled' do
    expect{dsc_xexchantimalwarescanning[:dsc_enabled] = -16}.to raise_error(Puppet::ResourceError)
  end

  it 'should not accept uint for dsc_enabled' do
    expect{dsc_xexchantimalwarescanning[:dsc_enabled] = 16}.to raise_error(Puppet::ResourceError)
  end

  it "should not accept empty password for dsc_credential" do
    expect{dsc_xexchantimalwarescanning[:dsc_credential] = {"user"=>"user", "password"=>""}}.to raise_error(Puppet::ResourceError)
  end

  it 'should not accept array for dsc_credential' do
    expect{dsc_xexchantimalwarescanning[:dsc_credential] = ["foo", "bar", "spec"]}.to raise_error(Puppet::ResourceError)
  end

  it 'should not accept boolean for dsc_credential' do
    expect{dsc_xexchantimalwarescanning[:dsc_credential] = true}.to raise_error(Puppet::ResourceError)
  end

  it 'should not accept int for dsc_credential' do
    expect{dsc_xexchantimalwarescanning[:dsc_credential] = -16}.to raise_error(Puppet::ResourceError)
  end

  it 'should not accept uint for dsc_credential' do
    expect{dsc_xexchantimalwarescanning[:dsc_credential] = 16}.to raise_error(Puppet::ResourceError)
  end

  it 'should not accept array for dsc_allowservicerestart' do
    expect{dsc_xexchantimalwarescanning[:dsc_allowservicerestart] = ["foo", "bar", "spec"]}.to raise_error(Puppet::ResourceError)
  end

  it 'should accept boolean for dsc_allowservicerestart' do
    dsc_xexchantimalwarescanning[:dsc_allowservicerestart] = true
    expect(dsc_xexchantimalwarescanning[:dsc_allowservicerestart]).to eq(true)
  end

  it "should accept boolean-like value 'true' and munge this value to boolean for dsc_allowservicerestart" do
    dsc_xexchantimalwarescanning[:dsc_allowservicerestart] = 'true'
    expect(dsc_xexchantimalwarescanning[:dsc_allowservicerestart]).to eq(true)
  end

  it "should accept boolean-like value 'false' and munge this value to boolean for dsc_allowservicerestart" do
    dsc_xexchantimalwarescanning[:dsc_allowservicerestart] = 'false'
    expect(dsc_xexchantimalwarescanning[:dsc_allowservicerestart]).to eq(false)
  end

  it "should accept boolean-like value 'True' and munge this value to boolean for dsc_allowservicerestart" do
    dsc_xexchantimalwarescanning[:dsc_allowservicerestart] = 'True'
    expect(dsc_xexchantimalwarescanning[:dsc_allowservicerestart]).to eq(true)
  end

  it "should accept boolean-like value 'False' and munge this value to boolean for dsc_allowservicerestart" do
    dsc_xexchantimalwarescanning[:dsc_allowservicerestart] = 'False'
    expect(dsc_xexchantimalwarescanning[:dsc_allowservicerestart]).to eq(false)
  end

  it "should accept boolean-like value :true and munge this value to boolean for dsc_allowservicerestart" do
    dsc_xexchantimalwarescanning[:dsc_allowservicerestart] = :true
    expect(dsc_xexchantimalwarescanning[:dsc_allowservicerestart]).to eq(true)
  end

  it "should accept boolean-like value :false and munge this value to boolean for dsc_allowservicerestart" do
    dsc_xexchantimalwarescanning[:dsc_allowservicerestart] = :false
    expect(dsc_xexchantimalwarescanning[:dsc_allowservicerestart]).to eq(false)
  end

  it 'should not accept int for dsc_allowservicerestart' do
    expect{dsc_xexchantimalwarescanning[:dsc_allowservicerestart] = -16}.to raise_error(Puppet::ResourceError)
  end

  it 'should not accept uint for dsc_allowservicerestart' do
    expect{dsc_xexchantimalwarescanning[:dsc_allowservicerestart] = 16}.to raise_error(Puppet::ResourceError)
  end

  # Configuration PROVIDER TESTS

  describe "powershell provider tests" do

    it "should successfully instanciate the provider" do
      described_class.provider(:powershell).new(dsc_xexchantimalwarescanning)
    end

    before(:each) do
      @provider = described_class.provider(:powershell).new(dsc_xexchantimalwarescanning)
    end

    describe "when dscmeta_module_name existing/is defined " do

      it "should compute powershell dsc test script with Invoke-DscResource" do
        expect(@provider.ps_script_content('test')).to match(/Invoke-DscResource/)
      end

      it "should compute powershell dsc test script with method Test" do
        expect(@provider.ps_script_content('test')).to match(/Method\s+=\s*'test'/)
      end

      it "should compute powershell dsc set script with Invoke-DscResource" do
        expect(@provider.ps_script_content('set')).to match(/Invoke-DscResource/)
      end

      it "should compute powershell dsc test script with method Set" do
        expect(@provider.ps_script_content('set')).to match(/Method\s+=\s*'set'/)
      end

    end

    describe "when dsc_resource has credentials" do

      it "should convert credential hash to a pscredential object" do
        expect(@provider.ps_script_content('test')).to match(/| new-pscredential'/)
      end

    end


  end
end
